<?php
/**
 * @package RSDirectory!
 * @copyright (C) 2013-2018 www.rsjoomla.com
 * @license GPL, http://www.gnu.org/licenses/gpl-3.0.html
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

require_once JPATH_ROOT . '/components/com_community/libraries/core.php';

class plgCommunityRSDirectory extends CApplications
{
	var $name = 'RSDirectory!';
	var $_name = 'rsdirectory';
		
	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);
			
		$lang = JFactory::getLanguage();
		$lang->load('com_rsdirectory', JPATH_ADMINISTRATOR);
		$lang->load('plg_community_rsdirectory', JPATH_ADMINISTRATOR);
			
		$this->name = JText::_('PLG_RSDIRECTORY_APPLICATION');
    }
		
	/**
	 * Method to get a list of entries.
	 *
	 * @access protected
	 *
	 * @param object $user
	 * @param int $limit
	 *
	 * @return array
	 */
	protected function _getEntries($user, $limit)
	{
		$db = JFactory::getDbo();
			
		$ordering = $this->params->get('ordering', 'start');
		$order = $this->params->get('order', 'ASC');
			
		$select = array(
			$db->qn('e') . '.*',
			$db->qn('u.name', 'author'),
			$db->qn('c.title', 'category_title'),
		);
			
		$query = $db->getQuery(true)
			   ->select($select)
			   ->from( $db->qn('#__rsdirectory_entries', 'e') )
			   ->innerJoin( $db->qn('#__users', 'u') . ' ON ' . $db->qn('e.user_id') . ' = ' . $db->qn('u.id') )
			   ->innerJoin( $db->qn('#__categories', 'c') . ' ON ' . $db->qn('e.category_id') . ' = ' . $db->qn('c.id') )
			   ->where( $db->qn('e.published') . ' = ' . $db->q(1) )
			   ->where( '(' . $db->qn('e.expiry_time') . ' = ' . $db->q('0000-00-00 00:00:00') . ' OR ' . $db->qn('e.expiry_time') . ' > ' . $db->q( JFactory::getDate()->toSql() ) . ')' )
			   ->where( $db->qn('e.user_id') . ' = ' . $db->q($user->id) )
			   ->order( $db->qn($ordering) . ' ' . $db->escape($order) );
				
		$db->setQuery($query, 0, $limit);
		$entries = $db->loadObjectList();
			
		if ( !empty($entries) )
		{
			return RSDirectoryHelper::getEntriesData($entries);
		}
			
		return $entries;
	}
		
	public function onProfileDisplay()
	{
		require_once JPATH_ADMINISTRATOR . '/components/com_rsdirectory/helpers/rsdirectory.php';
		JHtml::_('stylesheet', 'plugins/community/rsdirectory/rsdirectory/style.css', array('relative' => false, 'version' => 'auto'));
			
		$config	= CFactory::getConfig();
		$this->loadUserParams();
			
		$app = JFactory::getApplication();
		$user = CFactory::getRequestUser();
		$caching = $this->params->get('cache', 1);
		$entries = $this->_getEntries( $user, $this->userparams->get('count', 5) );
			
		if ($caching)
		{
			$caching = $app->get('caching');
		}
			
		$cache = JFactory::getCache('plgCommunityRSDirectory');
		$cache->setCaching($caching);
			
		$content = $cache->call( array($this , 'getEntriesHTML'), $entries, $user, $config );
			
		return $content;
	}
		
	/**
	 * Function to get entries HTML.
	 *
	 * @access public
	 *
	 * @param array $entries
	 * @param object $user
	 * @param object $config
	 *
	 * @return string
	 */
	public function getEntriesHTML($entries, $user, $config)
	{
		ob_start();
			
		echo '<div class="rsdir-entries-container">';
			
		if ( empty($entries) )
		{
			echo '<div>' . JText::sprintf( 'PLG_RSDIRECTORY_NO_ENTRIES_CREATED_BY_USER', RSDirectoryHelper::escapeHTML($user->name) ) . '</div>';
		}
		else
		{
			$rsconfig = RSDirectoryConfig::getInstance();
			$width = $rsconfig->get('small_thumbnail_width');
			$height = $rsconfig->get('small_thumbnail_height');
				
			$show_thumbs = $this->userparams->get('show_thumbs', 1);
			$show_info = $this->userparams->get('show_info', 1);
				
			$links = $this->params->get('links', 0);
			$opener = $links ? '' : ' target="_blank"';
				
			echo '<h3>' . JText::_('PLG_RSDIRECTORY_ENTRIES_CREATED') . '</h3>';
				
			echo '<ul class="rsdir-entries cStreamList cResetList">';
				
			foreach ($entries as $entry)
			{
				$url = JRoute::_( "index.php?option=com_rsdirectory&view=entry&id=" . RSDirectoryHelper::sef($entry->id, $entry->title) );
				$title = RSDirectoryHelper::escapeHTML($entry->title);
				unset($src);
					
				?>
					
				<li>
					<?php if ($show_thumbs) { ?>
					<a class="cStream-Avatar cFloat-L"<?php echo $opener; ?> href="<?php echo $url; ?>" title="<?php echo $title; ?>">
					<?php
						
					if ( !empty($entry->form->fields) )
					{
						$images_field = RSDirectoryHelper::findFormField('images', $entry->form->fields);
							
						if ( !empty($images_field->files) )
						{
							$src = RSDirectoryHelper::getImageURL($images_field->files[0]->hash, 'small');
								
							?>
								
							<img class="cAvatar" src="<?php echo $src; ?>" width="<?php echo $width; ?>" height="<?php echo $height; ?>" alt="<?php echo $title; ?>" />
								
							<?php
						}
					}
						
					if ( empty($src) )
					{
						?>
							
						<i class="rsdir-no-image cAvatar"></i>	
							
						<?php
					}
						
					?>
					</a>
					<?php } ?>
						
					<?php if ($show_thumbs) { ?>
					<div class="cStream-Content">
					<?php } ?>
						<div class="cStream-Headline">
							<a<?php echo $opener; ?> href="<?php echo $url; ?>" title="<?php echo $title; ?>">
								<?php echo $title; ?>
							</a>
						</div>
							
						<?php echo $show_info ? RSDirectoryHelper::getEntryMeta($entry, $entry->form) : ''; ?>
					<?php if ($show_thumbs) { ?>
					</div>
					<?php } ?>
				</li>
					
				<?php
			}
				
			echo '</ul>';
		}
			
		echo '</div>';
			
		?>
			
		<div class="app-box-footer">
			<a class="app-box-action" href="<?php echo JRoute::_('index.php?option=com_rsdirectory&view=entries'); ?>">
				<?php echo JText::_('PLG_RSDIRECTORY_ALL_ENTRIES'); ?>
			</a>
		</div>
			
		<?php
			
		$html = ob_get_contents();
		ob_end_clean();
			
		return $html;
	}
}